@@ -17,13 +17,14 @@
  *  License along with this library; if not, write to the Free
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: shout.c 11554 2006-06-09 23:09:33Z brendan $
+ * $Id: shout.c 18174 2012-02-02 00:16:36Z giles $
  */
 
 #ifdef HAVE_CONFIG_H
  #include <config.h>
 #endif
 
+#include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -37,6 +38,14 @@
 #include "shout_private.h"
 #include "util.h"
 
+#ifdef _MSC_VER
+# ifndef va_copy
+#  define va_copy(ap1, ap2) memcpy(&ap1, &ap2, sizeof(va_list))
+# endif
+# define vsnprintf	_vsnprintf
+# define inline 	_inline
+#endif
+
 /* -- local prototypes -- */
 static int queue_data(shout_queue_t *queue, const unsigned char *data, size_t len);
 static int queue_str(shout_t *self, const char *str);
@@ -718,7 +727,9 @@ int shout_set_format(shout_t *self, unsigned int format)
 	if (self->state != SHOUT_STATE_UNCONNECTED)
 		return self->error = SHOUTERR_CONNECTED;
 
-	if (format != SHOUT_FORMAT_OGG && format != SHOUT_FORMAT_MP3)
+	if (format != SHOUT_FORMAT_OGG
+         && format != SHOUT_FORMAT_MP3
+	 && format != SHOUT_FORMAT_WEBM)
 		return self->error = SHOUTERR_UNSUPPORTED;
 
 	self->format = format;
@@ -990,6 +1001,9 @@ static int try_connect (shout_t *self)
 		} else if (self->format == SHOUT_FORMAT_MP3) {
 			if ((rc = self->error = shout_open_mp3(self)) != SHOUTERR_SUCCESS)
                                 goto failure;
+		} else if (self->format == SHOUT_FORMAT_WEBM) {
+			if ((rc = self->error = shout_open_webm(self)) != SHOUTERR_SUCCESS)
+				goto failure;
 		} else {
                         rc = SHOUTERR_INSANE;
                         goto failure;
@@ -1006,10 +1020,11 @@ failure:
 	return rc;
 }
 
-static int try_write (shout_t *self, const void *data, size_t len)
+static int try_write (shout_t *self, const void *data_p, size_t len)
 {
     int ret;
     size_t pos = 0;
+    unsigned char *data = (unsigned char *)data_p;
 
     /* loop until whole buffer is written (unless it would block) */
     do {
@@ -1120,6 +1135,8 @@ static int create_http_request(shout_t *self)
 			break;
 		if (self->format == SHOUT_FORMAT_MP3 && queue_printf(self, "Content-Type: audio/mpeg\r\n"))
 			break;
+		if (self->format == SHOUT_FORMAT_WEBM && queue_printf(self, "Content-Type: video/webm\r\n"))
+			break;
 		if (queue_printf(self, "ice-name: %s\r\n", self->name ? self->name : "no name"))
 			break;
 		if (queue_printf(self, "ice-public: %d\r\n", self->public))
